pub struct BlendRenderer {
device: Arc<Device>,
queue: Arc<Queue>,
pipeline: RenderPipeline,
bind_group_layout: BindGroupLayout,
uniform_buffer: Buffer,
sampler: Sampler,
cached_bind_group: Option<CachedBindGroup>,
}Expand description
Blend renderer for double-presets.
Fields
device: Arc<Device>queue: Arc<Queue>pipeline: RenderPipelinebind_group_layout: BindGroupLayoutuniform_buffer: Buffersampler: Samplercached_bind_group: Option<CachedBindGroup>Cached bind group key and bind group for texture pair
Implementations
Sourceimpl BlendRenderer
impl BlendRenderer
Sourcepub fn new(
device: Arc<Device>,
queue: Arc<Queue>,
texture_format: TextureFormat,
) -> Result<Self>
pub fn new( device: Arc<Device>, queue: Arc<Queue>, texture_format: TextureFormat, ) -> Result<Self>
Create a new blend renderer.
Sourcefn is_cached(&self, key_a: usize, key_b: usize) -> bool
fn is_cached(&self, key_a: usize, key_b: usize) -> bool
Check if cached bind group matches texture pair
Sourcefn get_cached_bind_group(&self) -> Option<&BindGroup>
fn get_cached_bind_group(&self) -> Option<&BindGroup>
Get or create a cached bind group for the texture pair.
Sourcefn create_and_cache_bind_group(
&mut self,
texture_a: &TextureView,
texture_b: &TextureView,
)
fn create_and_cache_bind_group( &mut self, texture_a: &TextureView, texture_b: &TextureView, )
Create and cache a new bind group for the texture pair.